@@ -4,19 +4,28 @@ from functools import partial
 from typing import Iterable, Tuple
 
 import altair as alt
-import entrypoints
 import pandas as pd
 import streamlit as st
 
+try:
+    from streamlit import cache_data  # streamlit >= 1.18.0
+except ImportError:
+    from streamlit import experimental_memo as cache_data  # streamlit >= 0.89
+
 from .. import extra
 
+try:
+    from altair.utils.plugin_registry import NoSuchEntryPoint
+except ImportError:
+    from entrypoints import NoSuchEntryPoint
+
 try:
     alt.themes.enable("streamlit")
-except entrypoints.NoSuchEntryPoint:
+except NoSuchEntryPoint:
     st.altair_chart = partial(st.altair_chart, theme="streamlit")
 
 
-@st.experimental_memo
+@cache_data
 def get_data() -> pd.DataFrame:
     source = pd.read_csv(
         "https://raw.githubusercontent.com/vega/vega-datasets/next/data/stocks.csv"
@@ -25,7 +34,7 @@ def get_data() -> pd.DataFrame:
     return source
 
 
-@st.experimental_memo(ttl=60 * 60 * 24)
+@cache_data(ttl=60 * 60 * 24)
 def get_chart(data: pd.DataFrame) -> alt.Chart:
     hover = alt.selection_single(
         fields=["date"],
