@@ -3,10 +3,15 @@ from typing import Iterable
 import pandas as pd
 import streamlit as st
 
+try:
+    from streamlit import cache_data  # streamlit >= 1.18.0
+except ImportError:
+    from streamlit import experimental_memo as cache_data  # streamlit >= 0.89
+
 from .. import extra
 
 
-@st.experimental_memo
+@cache_data
 def get_dataframe() -> pd.DataFrame:
     df = pd.DataFrame(
         [
@@ -39,12 +44,12 @@ def get_dataframe() -> pd.DataFrame:
 
 
 @extra
-@st.experimental_memo
+@cache_data
 def table_with_images(df: pd.DataFrame, url_columns: Iterable):
 
     df_ = df.copy()
 
-    @st.experimental_memo
+    @cache_data
     def _path_to_image_html(path):
         return '<img src="' + path + '" width="60" >'
 
